# Generated by Django 5.1 on 2024-10-20 03:23

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0018_alter_customer_city'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='customer_group',
            field=models.ForeignKey(default=artd_customer.models.default_customer_group, help_text='Customer group.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customergroup', verbose_name='Customer group'),
        ),
    ]
