# Generated by Django 5.1 on 2024-10-20 02:48

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0013_customerdocumenttype_customerpersontype_customertype'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='customer',
            name='customer_person_type',
        ),
        migrations.RemoveField(
            model_name='customer',
            name='customer_type',
        ),
        migrations.RemoveField(
            model_name='customer',
            name='document_type',
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=datetime.datetime(2024, 10, 20, 2, 48, 36, 404342, tzinfo=datetime.timezone.utc), help_text='Date time on which the object was created.', verbose_name='Created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='external_id',
            field=models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='source',
            field=models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='status',
            field=models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status'),
        ),
        migrations.AddField(
            model_name='customerdocumenttype',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at'),
        ),
    ]
