# Generated by Django 5.1 on 2024-10-20 03:16

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0016_alter_customer_customer_person_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='tax_segment',
            field=models.ForeignKey(default=artd_customer.models.get_tax_segment, help_text='Tax segment.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.taxsegment', verbose_name='Tax segment'),
        ),
    ]
