# Generated by Django 5.1 on 2024-10-20 01:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0012_customer_vat_responsible'),
    ]

    operations = [
        migrations.CreateModel(
            name='CustomerDocumentType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='Name of the customer document type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer document type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Document Type',
                'verbose_name_plural': 'Customer Document Types',
            },
        ),
        migrations.CreateModel(
            name='CustomerPersonType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the customer person type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer person type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Person Type',
                'verbose_name_plural': 'Customer Person Types',
            },
        ),
        migrations.CreateModel(
            name='CustomerType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.JSONField(blank=True, help_text='Source of the object.', null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('name', models.CharField(help_text='Name of the customer type.', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code of the customer type.', max_length=100, verbose_name='Code')),
            ],
            options={
                'verbose_name': 'Customer Type',
                'verbose_name_plural': 'Customer Types',
            },
        ),
    ]
