from django.utils.translation import gettext_lazy as _

CUSTOMER_TYPES = [
    {
        "code": "customer",
        "name": "Customer",
    },
    {
        "code": "supplier",
        "name": "Supplier",
    },
    {
        "code": "other",
        "name": "Other",
    },
]

CUSTOMER_PERSON_TYPES = [
    {
        "code": "person",
        "name": "Person",
    },
    {
        "code": "company",
        "name": "Company",
    },
]

DOCUMENT_TYPES = [
    {
        "code": "dni",
        "name": "DNI",
    },
    {
        "code": "nit",
        "name": "NIT",
    },
    {
        "code": "passport",
        "name": "Passport",
    },
    {
        "code": "passport",
        "name": "Passport",
    },
    {
        "code": "Foreigners_id:_card",
        "name": "Foreigner's ID card",
    },
    {
        "code": "license",
        "name": "License",
    },
    {
        "code": "other",
        "name": "Other",
    },
]
