# Generated by Django 5.1 on 2024-10-20 03:20

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0017_alter_customer_tax_segment'),
        ('artd_location', '0002_alter_city_created_at_alter_city_status_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='city',
            field=models.ForeignKey(default=artd_customer.models.get_default_city, help_text='City of the customer.', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_location.city', verbose_name='City'),
        ),
    ]
