# Generated by Django 5.1 on 2024-10-20 01:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0011_customer_customer_person_type_customer_customer_type_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='vat_responsible',
            field=models.BooleanField(default=False, help_text='VAT responsible', verbose_name='VAT responsible'),
        ),
    ]
