TAX_SEGMENTS = [
    {
        "country_id": 45,
        "macro_tax_segment_id": 1,
        "macro_tax_segment_name": "Grandes contribuyentes",
        "macro_tax_segment_code": "grandes_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 1,
                "tax_segment_name": "Grandes contribuyentes",
                "tax_segment_code": "grandes_contribuyentes",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 2,
        "macro_tax_segment_name": "Medianos contribuyentes",
        "macro_tax_segment_code": "medianos_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 2,
                "tax_segment_name": "Medianos",
                "tax_segment_code": "medianos",
            },
            {
                "tax_segment_id": 3,
                "tax_segment_name": "Medianos altos",
                "tax_segment_code": "medianos_altos",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 3,
        "macro_tax_segment_name": "Pequeños contribuyentes",
        "macro_tax_segment_code": "pequeños_contribuyentes",
        "segments": [
            {
                "tax_segment_id": 4,
                "tax_segment_name": "Micro contribuyentes",
                "tax_segment_code": "micro_contribuyentes",
            },
            {
                "tax_segment_id": 5,
                "tax_segment_name": "Pequeños contribuyentes",
                "tax_segment_code": "pequenos_contribuyentes",
            },
            {
                "tax_segment_id": 6,
                "tax_segment_name": "Personas Jurídicas no declarantes",
                "tax_segment_code": "personas_juridicas_no_declarantes",
            },
        ],
    },
    {
        "country_id": 45,
        "macro_tax_segment_id": 4,
        "macro_tax_segment_name": "Personas Naturales",
        "macro_tax_segment_code": "personas_naturales",
        "segments": [
            {
                "tax_segment_id": 7,
                "tax_segment_name": "Personas Naturales declarantes",
                "tax_segment_code": "personas_naturales_declarantes",
            },
            {
                "tax_segment_id": 8,
                "tax_segment_name": "Personas Naturales no declarantes",
                "tax_segment_code": "personas_naturales_no_declarantes",
            },
        ],
    },
]
