# Generated by Django 5.1 on 2024-10-20 02:50

import artd_customer.models
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0015_customer_customer_person_type_customer_customer_type_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customer',
            name='customer_person_type',
            field=models.ForeignKey(default=artd_customer.models.get_default_customer_person_type, help_text='Customer person type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customerpersontype', verbose_name='Customer person type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='customer_type',
            field=models.ForeignKey(default=artd_customer.models.get_default_customer_type, help_text='Customer type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customertype', verbose_name='Customer type'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='document_type',
            field=models.ForeignKey(default=artd_customer.models.customer_document_type, help_text='Document type', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_customer.customerdocumenttype', verbose_name='Document type'),
        ),
    ]
