# Generated by Django 5.1 on 2024-10-19 22:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('artd_customer', '0010_macrotaxsegment_taxsegment_customer_tax_segment'),
    ]

    operations = [
        migrations.AddField(
            model_name='customer',
            name='customer_person_type',
            field=models.CharField(choices=[('person', 'Person'), ('company', 'Company')], default='person', help_text='Customer person type', max_length=50, verbose_name='Customer person type'),
        ),
        migrations.AddField(
            model_name='customer',
            name='customer_type',
            field=models.CharField(choices=[('customer', 'Customer'), ('supplier', 'Supplier'), ('other', 'Other')], default='customer', help_text='Customer type', max_length=50, verbose_name='Customer type'),
        ),
        migrations.AddField(
            model_name='customer',
            name='document_type',
            field=models.CharField(choices=[('dni', 'DNI'), ('nit', 'NIT'), ('passport', 'Passport'), ('passport', 'Passport'), ('Foreigners_id:_card', "Foreigner's ID card"), ('license', 'License'), ('other', 'Other')], default='dni', help_text='Document type', max_length=50, verbose_name='Document type'),
        ),
    ]
